[vte/vte-0-34] drawing: Interrupt attribute runs at graphic characters



commit 75b06e0b5fff57e8be8d6b61b97b687291f92478
Author: Egmont Koblinger <egmont gmail com>
Date:   Mon Sep 16 22:53:24 2013 +0200

    drawing: Interrupt attribute runs at graphic characters
    
    Graphic characters are drawn individually and directly, so they should interrupt
    a run of cells of the same attributes.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=707221

 src/vte.c |   17 +++--------------
 1 files changed, 3 insertions(+), 14 deletions(-)
---
diff --git a/src/vte.c b/src/vte.c
index fdae4bd..f0e4b6a 100644
--- a/src/vte.c
+++ b/src/vte.c
@@ -10673,21 +10673,10 @@ vte_terminal_draw_rows(VteTerminal *terminal,
                                         * in this chunk. */
                                        selected = vte_cell_is_selected(terminal, j, row, NULL);
                                        vte_terminal_determine_colors(terminal, cell, selected, &nfore, 
&nback);
                                        /* Graphic characters must be drawn individually. */
                                        if (vte_unichar_is_local_graphic(cell->c)) {
-                                               if (vte_terminal_draw_graphic(terminal,
-                                                                       cell->c,
-                                                                       nfore, nback,
-                                                                       FALSE,
-                                                                       start_x + j * column_width,
-                                                                       y,
-                                                                       column_width,
-                                                                       cell->attr.columns,
-                                                                       row_height)) {
-
-                                                       j += cell->attr.columns;
-                                                       continue;
-                                               }
+                                               break;
                                        }
                                        if (nfore != fore) {
                                                break;
@@ -10673,21 +10673,10 @@ vte_terminal_draw_rows(VteTerminal *terminal,
                                        vte_terminal_determine_colors(terminal, cell, selected, &nfore, 
&nback);
-                                       /* Graphic characters must be drawn individually. */
+                                       /* Graphic characters must be drawn individually and thus break the
+                                         * run of characters with the same attributes. */
                                        if (vte_unichar_is_local_graphic(cell->c)) {


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]